#Replication Code for Moral Support: How Moral Values Shape Foreign Policy Attitudes
#Joshua D. Kertzer, Kathleen E. Powers, Brian C. Rathbun, and Ravi Iyer
#January 2014
#This file replicates the results from the manuscript; File 2 replicates the results from the supplementary appendix

#### Loads the following libraries
library(foreign)
library(psych)
library(lmtest)
library(stargazer)
library(mediation)

#### Data (set working directory first)
data <- read.dta("MoralValues.dta")

#### 1: Generate factor scores for MI,CI,Isolationism
#MI
mi.dat <- cbind(data$foreignpi_1, data$foreignpi_2, data$foreignpi_3, data$foreignpi_4, data$foreignpi_5r, data$foreignpi_6)
fa.parallel(mi.dat) #Clearly one factor
mi.fit <- fa(mi.dat,nfactors=1, rotate="varimax",scores=TRUE, fm="pa")
mi.fit$loadings #look good
data$mi.s <- mi.fit$scores

#CI - dropped "war is never justified question", which doesn't load well
ci.dat <- cbind(data$foreignpi_7, data$foreignpi_8,  data$foreignpi_10, data$foreignpi_11, data$foreignpi_12)
fa.parallel(ci.dat) #Slightly more ambiguous, but still a decent one factor
ci.fit <- fa(ci.dat,nfactors=1, rotate="varimax",scores=TRUE, fm="pa")
ci.fit$loadings #look good
data$ci.s <- ci.fit$scores

#Isolationism
iso.dat <- cbind(data$foreignpi_13, data$foreignpi_14, data$foreignpi_15r, data$foreignpi_16, data$foreignpi_17)
fa.parallel(iso.dat) #One factor
iso.fit <- fa(iso.dat,nfactors=1, rotate="varimax",scores=TRUE, fm="pa")
iso.fit$loadings #looks good
data$iso.s <- iso.fit$scores

#### 2: Rescale our DVs and IVs of interest, all ranging from 0-1
rescale <- function(x){
	return((x-min(x,na.rm=TRUE))/(max(x-min(x,na.rm=TRUE),na.rm=TRUE)))
}

#MFQs
data$mfq_harm1 <- rescale(data$mfq_harm_avg)
data$mfq_fairness1 <- rescale(data$mfq_fairness_avg)
data$mfq_ingroup1<- rescale(data$mfq_ingroup_avg)
data$mfq_authority1 <- rescale(data$mfq_authority_avg)
data$mfq_purity1 <- rescale(data$mfq_purity_avg)

#FP batteries (ci2, mi2, iso2) are already scaled from 0-1
#So are ci, mi, iso (use these versions rather than ci2 mi2 iso2)

#FP battery factor scores
data$ci.s1 <- rescale(data$ci.s)
data$mi.s1 <- rescale(data$mi.s)
data$iso.s1 <- rescale(data$iso.s)

######2: Table 1: Foreign Policy batteries using factor score DVs

## Cooperative internationalism ##
#CI ~ MFQ
mod.ci1.s <- lm(ci.s1 ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1, data=data)
summary(mod.ci1.s)

#CI ~ MFQ + demographics
mod.ci.s1.s <- lm(ci.s1 ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1 + age + Male + education_2 + education_3 + education_4 + education_5, data=data)
summary(mod.ci.s1.s) 

#CI ~ MFQ + ideology
mod.ci.s.id <- lm(ci.s1 ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1 + age + Male + education_2 + education_3 + education_4 + education_5 + Liberal + Conservative + Libertarian, data=data)
summary(mod.ci.s.id)

## Militant internationalism ##
#MI ~ MFQ
mod.mi1.s <- lm(mi.s1 ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1, data=data)
summary(mod.mi1.s)

#MI ~ MFQ + demographics
mod.mi.s1.s <- lm(mi.s1 ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1 + age + Male + education_2 + education_3 + education_4 + education_5, data=data)
summary(mod.mi.s1.s)

#MI ~ MFQ + ideology
mod.mi.s.id <- lm(mi.s1 ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1 + age + Male + education_2 + education_3 + education_4 + education_5 + Liberal + Conservative + Libertarian, data=data)
summary(mod.mi.s.id)

## Isolationism ##
#Iso ~ MFQ
mod.iso1.s <- lm(iso.s1 ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1, data=data)
summary(mod.iso1.s)

#Iso ~ MFQ + demographics
mod.iso.s1.s <- lm(iso.s1 ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1 + age + Male + education_2 + education_3 + education_4 + education_5, data=data)
summary(mod.iso.s1.s)

#Iso ~ MFQ + ideology
mod.iso.s.id <- lm(iso.s1 ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1 + age + Male + education_2 + education_3 + education_4 + education_5 + Liberal + Conservative + Libertarian, data=data)
summary(mod.iso.s.id)

#Table 1
stargazer(mod.ci1.s, mod.ci.s1.s, mod.ci.s.id, mod.mi1.s, mod.mi.s1.s, mod.mi.s.id, mod.iso1.s, mod.iso.s1.s, mod.iso.s.id, title="Moral foundations of foreign policy orientations", omit.stat=c("LL", "ser", "f"), style="apsr", digits=3, label="tab:1")


###### 3: Specific policy attitudes (for Figure 1 and Appendix Table 6)

#Iraq ~ MFQ
mod.iraq1 <- lm(iraq ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1, data=data)
summary(mod.iraq1)

#Iraq ~ MFQ + demographics
mod.iraq2 <- lm(iraq ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1 + age + Male + education_2 + education_3 + education_4 + education_5, data=data)
summary(mod.iraq2) #Don't weight when also controlling for demographic variables

#Iran ~ MFQ
mod.iran1 <- lm(iran ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1, data=data)
summary(mod.iran1)

#Iran ~ MFQ + demographics
mod.iran2 <- lm(iran ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1 + age + Male + education_2 + education_3 + education_4 + education_5, data=data)
summary(mod.iran2) 

#Kyoto ~ MFQ
mod.kyoto1 <- lm(kyoto ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1, data=data)
summary(mod.kyoto1)

#Kyoto ~ MFQ + demographics
mod.kyoto2 <- lm(kyoto ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1 + age + Male + education_2 + education_3 + education_4 + education_5, data=data)
summary(mod.kyoto2) 

#Libya ~ MFQ
mod.lib1 <- lm(libya ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1, data=data)
summary(mod.lib1)

#Libya ~ <MFQ + demographics
mod.lib2 <- lm(libya ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1 + age + Male + education_2 + education_3 + education_4 + education_5, data=data)
summary(mod.lib2) 

#Results and plot in main text; regression table is Table 6 from the appendix
stargazer(mod.iraq1, mod.iraq2, mod.iran1, mod.iran2, mod.kyoto1, mod.kyoto2, mod.lib1, mod.lib2, title="Moral foundations of specific foreign policy attitudes", omit.stat=c("LL", "ser", "f"), style="apsr", digits=3, label="tab:2")


###### Figure 1: Coefficient plots of moral foundations on foreign policy attitudes
coefPlot <- function(mod){
	mat <- matrix(NA,nrow=length(mod$coef),ncol=3)
	rownames(mat) <- names(mod$coef)
	for (i in 1:nrow(mat)){
		mat[i,] <- c(mod$coef[i], mod$coef[i]-1.96*sqrt(diag(vcov(mod)))[i], mod$coef[i]+1.96*sqrt(diag(vcov(mod)))[i])
	}
	mat
}

temp <- coefPlot(mod.ci.s1.s)[2:6,]
par(mfrow=c(2,4), mar=c(5.1,1.8,4.1,0), oma=c(0,4,0,0))
#CI Panel
plot(0,0,xlim=c(-0.5,0.8), ylim=c(1,nrow(temp)), axes=FALSE, xlab="Effect size", ylab="", type="n", main="a) Cooperative Internationalism")

for (i in 1:nrow(temp)){
	points(temp[i,1],(nrow(temp)-(i-1)), pch=16)
	lines(x=c(temp[i,2],temp[i,3]),y=rep(nrow(temp)-(i-1),2))
}
abline(v=0)
axis(1)
box()
text(-0.56,seq(nrow(temp),1,by=-1),c("Harm", "Fairness", "Ingroup", "Authority", "Purity"), srt=0,cex=1, xpd=TRUE)


#text(-0.5,seq(nrow(temp),1,by=-1),c("Intercept","Harm", "Fairness", "Ingroup", "Authority", "Purity","Age", "Male", "High School", "Some College", "College/University", "Grad/Prof School"), srt=0,cex=0.8, xpd=TRUE)

temp <- coefPlot(mod.mi.s1.s)[2:6,]
plot(0,0,xlim=c(-0.5,0.8), ylim=c(1,nrow(temp)), axes=FALSE, xlab="Effect size", ylab="", type="n", main="b) Militant Internationalism")

for (i in 1:nrow(temp)){
	points(temp[i,1],(nrow(temp)-(i-1)), pch=16)
	lines(x=c(temp[i,2],temp[i,3]),y=rep(nrow(temp)-(i-1),2))
}
abline(v=0)
axis(1)
box()

temp <- coefPlot(mod.iso.s1.s)[2:6,]
plot(0,0,xlim=c(-0.5,0.8), ylim=c(1,nrow(temp)), axes=FALSE, xlab="Effect size", ylab="", type="n", main="c) Isolationism")

for (i in 1:nrow(temp)){
	points(temp[i,1],(nrow(temp)-(i-1)), pch=16)
	lines(x=c(temp[i,2],temp[i,3]),y=rep(nrow(temp)-(i-1),2))
}
abline(v=0)
axis(1)
box()

plot(0,0,axes=FALSE, type="n", xlab="")

temp <- coefPlot(mod.iraq2)[2:6,]
plot(0,0,xlim=c(-0.5,0.8), ylim=c(1,nrow(temp)), axes=FALSE, xlab="Effect size", ylab="", type="n", main="d) Iraq War")

for (i in 1:nrow(temp)){
	points(temp[i,1],(nrow(temp)-(i-1)), pch=16)
	lines(x=c(temp[i,2],temp[i,3]),y=rep(nrow(temp)-(i-1),2))
}
abline(v=0)
axis(1)
box()
text(-0.56,seq(nrow(temp),1,by=-1),c("Harm", "Fairness", "Ingroup", "Authority", "Purity"), srt=0,cex=1, xpd=TRUE)

temp <- coefPlot(mod.iraq2)[2:6,]
plot(0,0,xlim=c(-0.5,0.8), ylim=c(1,nrow(temp)), axes=FALSE, xlab="Effect size", ylab="", type="n", main="e) Iran Strike")

for (i in 1:nrow(temp)){
	points(temp[i,1],(nrow(temp)-(i-1)), pch=16)
	lines(x=c(temp[i,2],temp[i,3]),y=rep(nrow(temp)-(i-1),2))
}
abline(v=0)
axis(1)
box()

temp <- coefPlot(mod.kyoto2)[2:6,]
plot(0,0,xlim=c(-0.5,0.8), ylim=c(1,nrow(temp)), axes=FALSE, xlab="Effect size", ylab="", type="n", main="f) Kyoto Protocol")

for (i in 1:nrow(temp)){
	points(temp[i,1],(nrow(temp)-(i-1)), pch=16)
	lines(x=c(temp[i,2],temp[i,3]),y=rep(nrow(temp)-(i-1),2))
}
abline(v=0)
axis(1)
box()

temp <- coefPlot(mod.lib2)[2:6,]
plot(0,0,xlim=c(-0.5,0.8), ylim=c(1,nrow(temp)), axes=FALSE, xlab="Effect size", ylab="", type="n", main="g) Libya Intervention")

for (i in 1:nrow(temp)){
	points(temp[i,1],(nrow(temp)-(i-1)), pch=16)
	lines(x=c(temp[i,2],temp[i,3]),y=rep(nrow(temp)-(i-1),2))
}
abline(v=0)
axis(1)
box()

###### Figure 2: Nonparametric mediation analyses

data$ideo1 <- rescale(as.numeric(data$politics7way))
dat.mediate.ci <- data[which(!is.na(data$ci.s1)),]
dat.mediate.mi <- data[which(!is.na(data$mi.s1)),]
dat.mediate.iso <- data[which(!is.na(data$iso.s1)),]


model.m.ci <- lm(ideo1 ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1 + age + Male + education_2 + education_3 + education_4 + education_5 , data=dat.mediate.ci)
model.ci <- lm(ci.s1 ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1 + ideo1 + age + Male + education_2 + education_3 + education_4 + education_5 , data=dat.mediate.ci)
model.m.mi <- lm(ideo1 ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1 + age + Male + education_2 + education_3 + education_4 + education_5 , data=dat.mediate.mi)
model.mi <- lm(mi.s1 ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1 + ideo1 + age + Male + education_2 + education_3 + education_4 + education_5 , data=dat.mediate.mi)
model.m.iso <- lm(ideo1 ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1 + age + Male + education_2 + education_3 + education_4 + education_5 , data=dat.mediate.iso)
model.iso <- lm(iso.s1 ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1 + ideo1 + age + Male + education_2 + education_3 + education_4 + education_5 , data=dat.mediate.iso)

harm.mod.ci <- mediate(model.m.ci,model.ci, sims=1500, boot=FALSE, treat="mfq_harm1", mediator="ideo1")
fair.mod.ci <- mediate(model.m.ci,model.ci, sims=1500, boot=FALSE, treat="mfq_fairness1", mediator="ideo1")
ingroup.mod.ci <- mediate(model.m.ci,model.ci, sims=1500, boot=FALSE, treat="mfq_ingroup1", mediator="ideo1")
authority.mod.ci <- mediate(model.m.ci,model.ci, sims=1500, boot=FALSE, treat="mfq_authority1", mediator="ideo1")
purity.mod.ci <- mediate(model.m.ci,model.ci, sims=1500, boot=FALSE, treat="mfq_purity1", mediator="ideo1")

summary(harm.mod.ci)
summary(fair.mod.ci)
summary(ingroup.mod.ci)
summary(authority.mod.ci)
summary(purity.mod.ci)

#Individualizing avg: 
(0.404 + 0.6578)/2 #0.5309 (0.4691 through other paths)
#Binding avg:
(0.58456 + 0.7184 + 0.98132)/3 #0.7614267 (0.2386733 through other paths)

harm.mod.mi <- mediate(model.m.mi,model.mi, sims=1500, boot=FALSE, treat="mfq_harm1", mediator="ideo1")
fair.mod.mi <- mediate(model.m.mi,model.mi, sims=1500, boot=FALSE, treat="mfq_fairness1", mediator="ideo1")
ingroup.mod.mi <- mediate(model.m.mi,model.mi, sims=1500, boot=FALSE, treat="mfq_ingroup1", mediator="ideo1")
authority.mod.mi <- mediate(model.m.mi,model.mi, sims=1500, boot=FALSE, treat="mfq_authority1", mediator="ideo1")
purity.mod.mi <- mediate(model.m.mi,model.mi, sims=1500, boot=FALSE, treat="mfq_purity1", mediator="ideo1")

summary(harm.mod.mi)
summary(fair.mod.mi)
summary(ingroup.mod.mi)
summary(authority.mod.mi)
summary(purity.mod.mi)

#Individualzing avg:
(0.4898 + 1.4154)/2 #0.9526 (4.74% through other)
#Binding avg:
(0.3570 + 0.3281 + 0.7937)/3 #0.4929333 (50.70667% through other)

harm.mod.iso <- mediate(model.m.iso,model.iso, sims=1500, boot=FALSE, treat="mfq_harm1", mediator="ideo1")
fair.mod.iso <- mediate(model.m.iso,model.iso, sims=1500, boot=FALSE, treat="mfq_fairness1", mediator="ideo1")
ingroup.mod.iso <- mediate(model.m.iso,model.iso, sims=1500, boot=FALSE, treat="mfq_ingroup1", mediator="ideo1")
authority.mod.iso <- mediate(model.m.iso,model.iso, sims=1500, boot=FALSE, treat="mfq_authority1", mediator="ideo1")
purity.mod.iso <- mediate(model.m.iso,model.iso, sims=1500, boot=FALSE, treat="mfq_purity1", mediator="ideo1")

summary(harm.mod.iso)
summary(fair.mod.iso)
summary(ingroup.mod.iso)
summary(authority.mod.iso)
summary(purity.mod.iso)

medResults <- function(mod){
	return(c(mod$d.avg, mod$d.avg.ci, mod$z.avg, mod$z.avg.ci, mod$tau.coef, mod$tau.ci))
}

med.ci <- rbind(medResults(harm.mod.ci), medResults(fair.mod.ci), medResults(ingroup.mod.ci), medResults(authority.mod.ci), medResults(purity.mod.ci))
med.mi <- rbind(medResults(harm.mod.mi), medResults(fair.mod.mi), medResults(ingroup.mod.mi), medResults(authority.mod.mi), medResults(purity.mod.mi))
med.iso <- rbind(medResults(harm.mod.iso), medResults(fair.mod.iso), medResults(ingroup.mod.iso), medResults(authority.mod.iso), medResults(purity.mod.iso))


par(mfrow=c(1,3), mar=c(5.1,1.1,4.1,0), oma=c(0,4,0,0))
#CI Panel
plot(0,0,xlim=c(-0.4,0.6), ylim=c(1,15), axes=FALSE, xlab="", ylab="", type="n", main="a) Cooperative Internationalism")
	polygon(c(-0.5,0.6,0.6,-0.5),c(15.5,15.5,12.5,12.5), border=FALSE, col="gray92")
	polygon(c(-0.5,0.6,0.6,-0.5),c(9.5,9.5,6.5,6.5), border=FALSE, col="gray92")
	polygon(c(-0.5,0.6,0.6,-0.5),c(3.5,3.5,0.5,0.5), border=FALSE, col="gray92")

for (i in 1:5){
	for (j in c(1,4,7)){
		points(med.ci[i,j],(15-((i-1)*3+(j-1)/3)), pch=16)
		lines(c(med.ci[i,j+1], med.ci[i,j+2]),c(rep(15-((i-1)*3+(j-1)/3),2)))
	}
}
abline(v=0)
axis(1, xlab="Effect size")
for (i in seq(15,3,by=-3)){
	text(c("ACME", "Direct", "Total"),x=-0.4,y=c(i,i-1,i-2),cex=0.7)
}
mtext(c("Harm", "Fairness", "Ingroup", "Authority", "Purity"),side=2, at=seq(14,2,by=-3),line=2.5)

#MI Panel
plot(0,0,xlim=c(-0.4,0.6), ylim=c(1,15), axes=FALSE, xlab="", ylab="", type="n", main="b) Militant Internationalism")
polygon(c(-0.5,0.6,0.6,-0.5),c(15.5,15.5,12.5,12.5), border=FALSE, col="gray92")
	polygon(c(-0.5,0.6,0.6,-0.5),c(9.5,9.5,6.5,6.5), border=FALSE, col="gray92")
	polygon(c(-0.5,0.6,0.6,-0.5),c(3.5,3.5,0.5,0.5), border=FALSE, col="gray92")

for (i in 1:5){
	for (j in c(1,4,7)){
		points(med.mi[i,j],(15-((i-1)*3+(j-1)/3)), pch=16)
		lines(c(med.mi[i,j+1], med.mi[i,j+2]),c(rep(15-((i-1)*3+(j-1)/3),2)))
	}
}
abline(v=0)
axis(1, xlab="Effect size")

#Iso panel
plot(0,0,xlim=c(-0.4,0.6), ylim=c(1,15), axes=FALSE, xlab="", ylab="", type="n", main="c) Isolationism")
	polygon(c(-0.5,0.6,0.6,-0.5),c(15.5,15.5,12.5,12.5), border=FALSE, col="gray92")
	polygon(c(-0.5,0.6,0.6,-0.5),c(9.5,9.5,6.5,6.5), border=FALSE, col="gray92")
	polygon(c(-0.5,0.6,0.6,-0.5),c(3.5,3.5,0.5,0.5), border=FALSE, col="gray92")

for (i in 1:5){
	for (j in c(1,4,7)){
		points(med.iso[i,j],(15-((i-1)*3+(j-1)/3)), pch=16)
		lines(c(med.iso[i,j+1], med.iso[i,j+2]),c(rep(15-((i-1)*3+(j-1)/3),2)))
	}
}
abline(v=0)
axis(1, xlab="Effect size")


