#Replication Code for Moral Support: How Moral Values Shape Foreign Policy Attitudes
#Joshua D. Kertzer, Kathleen E. Powers, Brian C. Rathbun, and Ravi Iyer
#January 2014
#This file replicates the results from the supplementary appendices; File 1 replicates the results from the manuscript

#### Loads the following libraries
library(foreign)
library(psych)
library(lmtest)
library(stargazer)
library(mediation)

#### Data (set working directory first)
data <- read.dta("MoralValues.dta")


############ Appendix

##### Appendix §1: Reliabilities
alpha(as.data.frame(mi.dat)) #0.84 
alpha(as.data.frame(ci.dat)) #0.88
alpha(as.data.frame(iso.dat)) #0.78

##### Appendix §3: Table 1: Survey Sample Characteristics
table(data$Male)/sum(table(data$Male))
table(data$age_2)/(sum(table(data$age_2)))
table(data$age_3)/(sum(table(data$age_3)))
table(data$age_4)/(sum(table(data$age_4)))
table(data$age_5)/(sum(table(data$age_5)))
table(data$education_1)/(sum(table(data$education_1)))
table(data$education_2)/(sum(table(data$education_2)))
table(data$education_3)/(sum(table(data$education_3)))
table(data$education_4)/(sum(table(data$education_4)))
table(data$education_5)/(sum(table(data$education_5)))

#Weighted sample characteristics: use Stata pweight
#age
233.8058/(1234.65+233.8058)
559.6486/(908.8098+559.6486)
471.4411/(997.0173+471.4411)
201.0447/(201.0447+1267.41)

#Education
148.2631/(1320.2+148.2631)
192.6043/(1275.85+192.6043)
391.543/(1076.92 + 391.543)
541.3798/(927.0786+541.3798)
192.9556/(1275.5+192.9556)

#Male
823.6498/(644.8087+823.6498)

##### Appendix §3: Table 2: Foreign policy batteries (weighted)

#CI ~ MFQ, weighted
mod.ci1w.s <- lm(ci.s1 ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1, weights=webal2, data=data)
summary(mod.ci1w.s)

#MI ~ MFQ, weighted
mod.mi1w.s <- lm(mi.s1 ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1, weights=webal2, data=data)
summary(mod.mi1w.s)

#Iso ~ MFQ, weighted
mod.iso1w.s <- lm(iso.s1 ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1, weights=webal2, data=data)
summary(mod.iso1w.s)

stargazer(mod.ci1.s, mod.ci1w.s, mod.mi1.s, mod.mi1w.s, mod.iso1.s, mod.iso1w.s, mod.iso.s1.s, title="Moral foundations of foreign policy orientations (weighted)", omit.stat=c("LL", "ser", "f"), style="apsr", digits=3, label="tab:app2")

##### Appendix §3.1: Table 3: Policy attitudes (weighted)

#iraq ~ Haidt, weighted
mod.iraq1w <- lm(iraq ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1, weights=webal2, data=data)
summary(mod.iraq1w)

#iran ~ Haidt, weighted
mod.iran1w <- lm(iran ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1, weights=webal2, data=data)
summary(mod.iran1w)

#kyoto ~ Haidt, weighted
mod.kyoto1w <- lm(kyoto ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1, weights=webal2, data=data)
summary(mod.kyoto1w)

#Libya ~ Haidt, weighted
mod.lib1w <- lm(libya ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1, weights=webal2, data=data)
summary(mod.lib1w)

stargazer(mod.iraq1, mod.iraq1w, mod.iran1, mod.iran1w, mod.kyoto1, mod.kyoto1w, mod.lib1, mod.lib1, title="Moral foundations of foreign policy attitudes (weighted)", omit.stat=c("LL", "ser", "f"), style="apsr", digits=3, label="tab:app2")

##### Appendix §3.2: Table 4: Foreign Policy Batteries by Interest in Politics

data$attention1 <- rep(NA, nrow(data))
data$attention1[which(data$political_attention == "Very much interested")] <- 1
data$attention1[which(data$political_attention == "Not much interested" | data$political_attention == "Somewhat interested")] <- 0

## Cooperative internationalism ##
#CI ~ MFQ
summary(mod.ci.s1.s)
mod.ci1.at0 <- lm(ci.s1 ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1 + age + Male + education_2 + education_3 + education_4 + education_5, data=subset(data, data$attention==0))
summary(mod.ci1.at0)
mod.ci1.at1 <- lm(ci.s1 ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1 + age + Male + education_2 + education_3 + education_4 + education_5, data=subset(data, data$attention==1))
summary(mod.ci1.at1)

## Militant internationalism ##
#MI ~ MFQ
summary(mod.mi.s1.s)
mod.mi1.at0 <- lm(mi.s1 ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1 + age + Male + education_2 + education_3 + education_4 + education_5, data=subset(data, data$attention==0))
summary(mod.mi1.at0)
mod.mi1.at1 <- lm(mi.s1 ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1 + age + Male + education_2 + education_3 + education_4 + education_5, data=subset(data, data$attention==1))
summary(mod.mi1.at1)


## Isolationism ##
#Iso ~ MFQ
summary(mod.iso.s1.s)
mod.iso1.at0 <- lm(iso.s1 ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1 + age + Male + education_2 + education_3 + education_4 + education_5, data=subset(data, data$attention==0))
summary(mod.iso1.at0)
mod.iso1.at1 <- lm(iso.s1 ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1+ age + Male + education_2 + education_3 + education_4 + education_5, data=subset(data, data$attention==1))
summary(mod.iso1.at1)

stargazer(mod.ci.s1.s, mod.ci1.at0, mod.ci1.at1, mod.mi.s1.s, mod.mi1.at0, mod.mi1.at1, mod.iso.s1.s, mod.iso1.at0, mod.iso1.at1, title="Moral foundations of foreign policy orientations: additive scores", omit.stat=c("LL", "ser", "f"), style="apsr", digits=3, label="tab:attention")

attention.ci <- cbind(coef(mod.ci1.at0), coef(mod.ci1.at1)) - coef(mod.ci.s1.s)
attention.mi <- cbind(coef(mod.mi1.at0), coef(mod.mi1.at1)) - coef(mod.mi.s1.s)
attention.iso <- cbind(coef(mod.iso1.at0), coef(mod.iso1.at1)) - coef(mod.iso.s1.s)

apply(attention.ci[-c(1,7:12),], 2, mean) #Low attention coefs an average of 0.035 units lower; high attention coefs an average of 0.020 units higher
apply(attention.mi[-c(1,7:12),], 2, mean) #Low attention coefs an average of 0.033 units lower, high attention coefs 0.011 units higher
apply(attention.iso[-c(1,7:12),], 2, mean) #Low attention coefs an average of 0.054 units higher, high attention coefs an average of 0.017 units lower


##### Appendix §3.3: Figure 1: Liberals and conservatives rely on different moral foundations

harm.id <- c(mean(data$mfq_harm1[data$Liberal==1], na.rm=TRUE), mean(data$mfq_harm1[data$Moderate==1], na.rm=TRUE), mean(data$mfq_harm1[data$Conservative==1], na.rm=TRUE), mean(data$mfq_harm1[data$Libertarian==1], na.rm=TRUE))
fair.id <- c(mean(data$mfq_fairness1[data$Liberal==1], na.rm=TRUE), mean(data$mfq_fairness1[data$Moderate==1], na.rm=TRUE), mean(data$mfq_fairness1[data$Conservative==1], na.rm=TRUE), mean(data$mfq_fairness1[data$Libertarian==1], na.rm=TRUE))
ingroup.id <- c(mean(data$mfq_ingroup1[data$Liberal==1], na.rm=TRUE), mean(data$mfq_ingroup1[data$Moderate==1], na.rm=TRUE), mean(data$mfq_ingroup1[data$Conservative==1], na.rm=TRUE), mean(data$mfq_ingroup1[data$Libertarian==1], na.rm=TRUE))
authority.id <- c(mean(data$mfq_authority1[data$Liberal==1], na.rm=TRUE), mean(data$mfq_authority1[data$Moderate==1], na.rm=TRUE), mean(data$mfq_authority1[data$Conservative==1], na.rm=TRUE), mean(data$mfq_authority1[data$Libertarian==1], na.rm=TRUE))
purity.id <- c(mean(data$mfq_purity1[data$Liberal==1], na.rm=TRUE), mean(data$mfq_purity1[data$Moderate==1], na.rm=TRUE), mean(data$mfq_purity1[data$Conservative==1], na.rm=TRUE), mean(data$mfq_purity1[data$Libertarian==1], na.rm=TRUE))

plot(0,0,ylim=c(0,1), xlim=c(1,4), xlab="", ylab="Mean score", axes=FALSE)
lines(harm.id, type="o", lty=5)
lines(fair.id, type="o", lty=1)
lines(ingroup.id, type="o", lty=2)
lines(authority.id, type="o", lty=4)
lines(purity.id, type="o", lty=3)
axis(1,at=c(1:4), c("Liberal", "Moderate", "Conservative", "Libertarian"))
axis(2)
box()
text(1.05,0.23,"Purity",srt=20,cex=0.7)
text(1.05,0.37,"Authority",srt=20,cex=0.7)
text(1.05,0.45,"Ingroup",srt=15,cex=0.7)
text(1.05,0.71,"Harm",srt=-21,cex=0.7)
text(1.05,0.8,"Fairness",srt=-20,cex=0.7)

##### Appendix §3: Table 5: Foreign Policy Batteries by Education

#By education
ed5 <- data$education_1 + 2*data$education_2 + 3*data$education_3 + 4*data$education_4 + 5*data$education_5
summary(ed5)

data$college1 <- rep(NA, nrow(data))
data$college1[which(ed5 >=4)] <- 1
data$college1[which(ed5 <4)] <- 0

summary(mod.ci.s1.s)
mod.ci1.ed0 <- lm(ci.s1 ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1 + age + Male, data=subset(data, data$college1==0))
summary(mod.ci1.ed0)
mod.ci1.ed1 <- lm(ci.s1 ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1 + age + Male , data=subset(data, data$college1==1))
summary(mod.ci1.ed1)

## Militant internationalism ##
#MI ~ MFQ
summary(mod.mi.s1.s)
mod.mi1.ed0 <- lm(mi.s1 ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1 + age + Male , data=subset(data, data$college1==0))
summary(mod.mi1.ed0)
mod.mi1.ed1 <- lm(mi.s1 ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1 + age + Male , data=subset(data, data$college1==1))
summary(mod.mi1.ed1)

## Isolationism ##
#Iso ~ MFQ
summary(mod.iso.s1.s)
mod.iso1.ed0 <- lm(iso.s1 ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1 + age + Male , data=subset(data, data$college1==0))
summary(mod.iso1.ed0)
mod.iso1.ed1 <- lm(iso.s1 ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1+ age + Male , data=subset(data, data$college1==1))
summary(mod.iso1.ed1)

mod.ci1.ed <- lm(ci.s1 ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1 + age + Male, data=data)
mod.mi1.ed <- lm(mi.s1 ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1 + age + Male, data=data)
mod.iso1.ed <- lm(iso.s1 ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1 + age + Male, data=data)

education.ci <- cbind(coef(mod.ci1.ed0), coef(mod.ci1.ed1)) - coef(mod.ci1.ed)
education.mi <- cbind(coef(mod.mi1.ed0), coef(mod.mi1.ed1)) - coef(mod.mi1.ed)
education.iso <- cbind(coef(mod.iso1.ed0), coef(mod.iso1.ed1)) - coef(mod.iso1.ed)

apply(education.ci[-c(1,7:8),], 2, mean) #Low educated participants are about 0.026 units lower, high educated about 0.016 units higher
apply(education.mi[-c(1,7:8),], 2, mean) #Low educated participants are about 0.025 units higher, high educated about 0.013 units lower
apply(education.iso[-c(1,7:8),], 2, mean) #Low educated participants are about 0.012 units higher, high educated about 0.008 units lower

stargazer(mod.ci1.ed, mod.ci1.ed0, mod.ci1.ed1, mod.mi1.ed, mod.mi1.ed0, mod.mi1.ed1, mod.iso1.ed, mod.iso1.ed0, mod.iso1.ed1, title="Moral foundations of foreign policy orientations by education", omit.stat=c("LL", "ser", "f"), style="apsr", digits=3, label="tab:education")



###### Appendix §4: Figure 2: Distribution of CI and MI factor scores, on a percentile scale
library(ggplot2)

#Break data down into 25ths
p <- 25

#Percentiles
c.x <- quantile(data$ci.s1, seq(0,1,length.out=(p+1)), na.rm=TRUE)
m.x <- quantile(data$mi.s1, seq(0,1,length.out=(p+1)), na.rm=TRUE)

#Alternately, just raw scores - results are substantively similar
c.x <- m.x <- seq(0,1,length.out=(p+1))

cm.mat <- as.data.frame(matrix(NA, nrow=p^2,ncol=3))
colnames(cm.mat) <- c("CI","MI","Proportion")
cm.mat[,1] <- rep(seq(0.05,1,length.out=p),p)
cm.mat[,2] <- rep(seq(0.05,1,length.out=p),each=p)
length(data$ci.s1) - length(which(is.na(data$ci.s1) | is.na(data$mi.s1))) #1937 is our denominator

for (i in 1:nrow(cm.mat)){
	x <- cm.mat[i,1]/0.05
	z <- cm.mat[i,2]/0.05
	cm.mat[i,3] <- length(which(data$ci.s1 <= c.x[x + 1] & data$ci.s1 >= c.x[x] & data$mi.s1 <= m.x[z + 1] & data$mi.s1 >= m.x[z]))/1944
}

qplot(CI,MI,data=cm.mat, geom="tile", fill=Proportion) + theme_bw() + scale_fill_gradient(low="gold", high="red")


###### Appendix §5: Table 6: Foreign policy attitude regression table
#Iraq ~ MFQ
mod.iraq1 <- lm(iraq ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1, data=data)
summary(mod.iraq1)

#Iraq ~ MFQ + demographics
mod.iraq2 <- lm(iraq ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1 + age + Male + education_2 + education_3 + education_4 + education_5, data=data)
summary(mod.iraq2) #Don't weight when also controlling for demographic variables

#Iran ~ MFQ
mod.iran1 <- lm(iran ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1, data=data)
summary(mod.iran1)

#Iran ~ MFQ + demographics
mod.iran2 <- lm(iran ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1 + age + Male + education_2 + education_3 + education_4 + education_5, data=data)
summary(mod.iran2) 

#Kyoto ~ MFQ
mod.kyoto1 <- lm(kyoto ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1, data=data)
summary(mod.kyoto1)

#Kyoto ~ MFQ + demographics
mod.kyoto2 <- lm(kyoto ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1 + age + Male + education_2 + education_3 + education_4 + education_5, data=data)
summary(mod.kyoto2) 

#Libya ~ MFQ
mod.lib1 <- lm(libya ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1, data=data)
summary(mod.lib1)

#Libya ~ <MFQ + demographics
mod.lib2 <- lm(libya ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1 + age + Male + education_2 + education_3 + education_4 + education_5, data=data)
summary(mod.lib2) 

stargazer(mod.iraq1, mod.iraq2, mod.iran1, mod.iran2, mod.kyoto1, mod.kyoto2, mod.lib1, mod.lib2, title="Moral foundations of specific foreign policy attitudes", omit.stat=c("LL", "ser", "f"), style="apsr", digits=3, label="tab:2")




###### Appendix §6.1: Table 7: Foreign policy orientations, additive scores

## Calculate and rescale additive scales, making sure they range from 0-1
data$ci <- rescale(apply(ci.dat, 1, sum, na.rm=TRUE))
data$mi <- rescale(apply(mi.dat, 1, sum, na.rm=TRUE))
data$iso <- rescale(apply(iso.dat, 1, sum, na.rm=TRUE))

## Cooperative internationalism ##
#CI ~ Haidt
mod.ci1 <- lm(ci ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1, data=data)
summary(mod.ci1)

#CI ~ Haidt, weighted
mod.ci1w <- lm(ci ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1, weights=webal2, data=data)
summary(mod.ci1w)

#CI ~ Haidt + demographics
mod.ci2 <- lm(ci ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1 + age + Male + education_2 + education_3 + education_4 + education_5, data=data)
summary(mod.ci2) #Don't weight when also controlling for demographic variables

## Militant internationalism ##
#MI ~ Haidt
mod.mi1 <- lm(mi ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1, data=data)
summary(mod.mi1)

#MI ~ Haidt, weighted
mod.mi1w <- lm(mi ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1, weights=webal2, data=data)
summary(mod.mi1w)

#MI ~ Haidt + demographics
mod.mi2 <- lm(mi ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1 + age + Male + education_2 + education_3 + education_4 + education_5, data=data)
summary(mod.mi2)

## Isolationism ##
#Iso ~ Haidt
mod.iso1 <- lm(iso ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1, data=data)
summary(mod.iso1)

#Iso ~ Haidt, weighted
mod.iso1w <- lm(iso ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1, weights=webal2, data=data)
summary(mod.iso1w)

#Iso ~ Haidt + demographics
mod.iso2 <- lm(iso ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1 + age + Male + education_2 + education_3 + education_4 + education_5, data=data)
summary(mod.iso2)

### Summary table
stargazer(mod.ci1, mod.ci1w, mod.ci2, mod.mi1, mod.mi1w, mod.mi2, mod.iso1, mod.iso1w, mod.iso2, title="Moral foundations of foreign policy orientations: additive scores", omit.stat=c("LL", "ser", "f"), style="apsr", digits=3, label="tab:app4")

####### Appendix §6.2 Tables 8-10:  Seemingly unrelated regressions
#Note: easier to do than a multivariate probit
library(systemfit)
#MI model

#Get rid of data with missing obs.
mi.dat2 <- subset(data, !(is.na(mi2)))

mi.1 <- foreignpi_1 ~ mfq_harm_avg + mfq_fairness_avg + mfq_ingroup_avg + mfq_authority_avg + mfq_purity_avg + age + Male + education_2 + education_3 + education_4 + education_5
mi.2 <- foreignpi_2 ~ mfq_harm_avg + mfq_fairness_avg + mfq_ingroup_avg + mfq_authority_avg + mfq_purity_avg + age + Male + education_2 + education_3 + education_4 + education_5
mi.3 <- foreignpi_3 ~ mfq_harm_avg + mfq_fairness_avg + mfq_ingroup_avg + mfq_authority_avg + mfq_purity_avg + age + Male + education_2 + education_3 + education_4 + education_5
mi.4 <- foreignpi_4 ~ mfq_harm_avg + mfq_fairness_avg + mfq_ingroup_avg + mfq_authority_avg + mfq_purity_avg + age + Male + education_2 + education_3 + education_4 + education_5
mi.5 <- foreignpi_5r ~ mfq_harm_avg + mfq_fairness_avg + mfq_ingroup_avg + mfq_authority_avg + mfq_purity_avg + age + Male + education_2 + education_3 + education_4 + education_5
mi.6 <- foreignpi_6 ~ mfq_harm_avg + mfq_fairness_avg + mfq_ingroup_avg + mfq_authority_avg + mfq_purity_avg + age + Male + education_2 + education_3 + education_4 + education_5

system.mi <- systemfit(method="SUR", list(mi.1, mi.2, mi.3, mi.4, mi.5, mi.6), data=mi.dat2)
summary(system.mi)

#CI model
ci.dat2 <- subset(data, !(is.na(ci2)))

ci.1 <- foreignpi_7 ~ mfq_harm_avg + mfq_fairness_avg + mfq_ingroup_avg + mfq_authority_avg + mfq_purity_avg + age + Male + education_2 + education_3 + education_4 + education_5
ci.2 <- foreignpi_8 ~ mfq_harm_avg + mfq_fairness_avg + mfq_ingroup_avg + mfq_authority_avg + mfq_purity_avg + age + Male + education_2 + education_3 + education_4 + education_5
ci.4 <- foreignpi_10 ~ mfq_harm_avg + mfq_fairness_avg + mfq_ingroup_avg + mfq_authority_avg + mfq_purity_avg + age + Male + education_2 + education_3 + education_4 + education_5
ci.5 <- foreignpi_11 ~ mfq_harm_avg + mfq_fairness_avg + mfq_ingroup_avg + mfq_authority_avg + mfq_purity_avg + age + Male + education_2 + education_3 + education_4 + education_5
ci.6 <- foreignpi_12 ~ mfq_harm_avg + mfq_fairness_avg + mfq_ingroup_avg + mfq_authority_avg + mfq_purity_avg + age + Male + education_2 + education_3 + education_4 + education_5

system.ci <- systemfit(method="SUR", list(ci.1, ci.2, ci.4, ci.5, ci.6), data=ci.dat2)
summary(system.ci)

#ISO model
iso.dat2 <- subset(data, !(is.na(iso2)))

iso.1 <- foreignpi_13 ~ mfq_harm_avg + mfq_fairness_avg + mfq_ingroup_avg + mfq_authority_avg + mfq_purity_avg + age + Male + education_2 + education_3 + education_4 + education_5
iso.2 <- foreignpi_14 ~ mfq_harm_avg + mfq_fairness_avg + mfq_ingroup_avg + mfq_authority_avg + mfq_purity_avg + age + Male + education_2 + education_3 + education_4 + education_5
iso.3 <- foreignpi_15r ~ mfq_harm_avg + mfq_fairness_avg + mfq_ingroup_avg + mfq_authority_avg + mfq_purity_avg + age + Male + education_2 + education_3 + education_4 + education_5
iso.4 <- foreignpi_16 ~ mfq_harm_avg + mfq_fairness_avg + mfq_ingroup_avg + mfq_authority_avg + mfq_purity_avg + age + Male + education_2 + education_3 + education_4 + education_5
iso.5 <- foreignpi_17 ~ mfq_harm_avg + mfq_fairness_avg + mfq_ingroup_avg + mfq_authority_avg + mfq_purity_avg + age + Male + education_2 + education_3 + education_4 + education_5

system.iso <- systemfit(method="SUR", list(iso.1, iso.2, iso.3, iso.4, iso.5), data=iso.dat2)
summary(system.iso, digits=3)

library(xtable)

sur.ci <- cbind(system.ci$eq[[1]]$coefficients, system.ci$eq[[2]]$coefficients, system.ci$eq[[3]]$coefficients, system.ci$eq[[4]]$coefficients, system.ci$eq[[5]]$coefficients)

xtable(sur.ci,digits=3)

sur.mi <- cbind(system.mi$eq[[1]]$coefficients, system.mi$eq[[2]]$coefficients, system.mi$eq[[3]]$coefficients, system.mi$eq[[4]]$coefficients, system.mi$eq[[5]]$coefficients, system.mi$eq[[6]]$coefficients)

xtable(sur.mi, digits=3)

sur.iso <- cbind(system.iso$eq[[1]]$coefficients, system.iso$eq[[2]]$coefficients, system.iso$eq[[3]]$coefficients, system.iso$eq[[4]]$coefficients, system.iso$eq[[5]]$coefficients)

xtable(sur.iso, digits=3)

###### Appendix §6.3: Table 11 Exploratory factor scores

fpbat.dat <- cbind(mi.dat,ci.dat,iso.dat)
fa.parallel(fpbat.dat) #3 factors, 2 components
fpbat.fit <- fa(fpbat.dat,nfactors=3, rotate="varimax", scores=TRUE, fm="pa")

data$scoreMI <- rescale(fpbat.fit$scores[,1])
data$scoreCI <- rescale(fpbat.fit$scores[,2])
data$scoreIso <- rescale(fpbat.fit$scores[,3])

xtable(cbind(fpbat.fit$loadings[,2], fpbat.fit$loadings[,1], fpbat.fit$loadings[,3]), digits=3)

#Comparing 2 and 3 factor solution
#3 factors
fpbat.dat <- cbind(mi.dat,ci.dat,iso.dat)
fa.parallel(fpbat.dat) #3 factors, 2 components
fpbat.fit <- fa(fpbat.dat,nfactors=3, rotate="varimax", scores=TRUE, fm="pa")

data$scoreMI <- rescale(fpbat.fit$scores[,1])
data$scoreCI <- rescale(fpbat.fit$scores[,2])
data$scoreIso <- rescale(fpbat.fit$scores[,3])
fpbat.fit #RMSEA = 0.05, BIC = -119.85, TLI =0.962

#2 factors
fpbat.fit2 <- fa(fpbat.dat,nfactors=2, rotate="varimax", scores=TRUE, fm="pa")
data$scorefac1 <- rescale(fpbat.fit$scores[,1])
data$scorefac2 <- rescale(fpbat.fit$scores[,2])
xtable(cbind(fpbat.fit2$loadings[,1], fpbat.fit$loadings[,2]), digits=3)
fpbat.fit2 #RMSEA =0.079, BIC = 511.9, TLI = 0.906



###### Appendix §6.3 Table 12: Foreign policy batteries: exploratory factor scores

## Cooperative internationalism ##
#CI ~ MFQ
mod.ci1.s3 <- lm(scoreCI ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1, data=data)
summary(mod.ci1.s3)

#CI ~ MFQ, weighted
mod.ci1w.s3 <- lm(scoreCI ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1, weights=webal2, data=data)
summary(mod.ci1w.s3)

#CI ~ MFQ + demographics
mod.ci.s1.s3 <- lm(scoreCI ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1 + age + Male + education_2 + education_3 + education_4 + education_5, data=data)
summary(mod.ci.s1.s3) #Don't weight when also controlling for demographic variables

## Militant internationalism ##
#MI ~ MFQ
mod.mi1.s3 <- lm(scoreMI ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1, data=data)
summary(mod.mi1.s3)

#MI ~ MFQ, weighted
mod.mi1w.s3 <- lm(scoreMI ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1, weights=webal2, data=data)
summary(mod.mi1w.s3)

#MI ~ MFQ + demographics
mod.mi.s1.s3 <- lm(scoreMI ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1 + age + Male + education_2 + education_3 + education_4 + education_5, data=data)
summary(mod.mi.s1.s3)

## Isolationism ##
#Iso ~ MFQ
mod.iso1.s3 <- lm(scoreIso ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1, data=data)
summary(mod.iso1.s3)

#Iso ~ MFQ, weighted
mod.iso1w.s3 <- lm(scoreIso ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1, weights=webal2, data=data)
summary(mod.iso1w.s3)

#Iso ~ MFQ + demographics
mod.iso.s1.s3 <- lm(scoreIso ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1 + age + Male + education_2 + education_3 + education_4 + education_5, data=data)
summary(mod.iso.s1.s3)

### Summary table
stargazer(mod.ci1.s3, mod.ci1w.s3, mod.ci.s1.s3, mod.mi1.s3, mod.mi1w.s3, mod.mi.s1.s3, mod.iso1.s3, mod.iso1w.s3, mod.iso.s1.s3, title="Foreign policy batteries: exploratory factor scores", omit.stat=c("LL", "ser", "f"), style="apsr", digits=3, label="tab:app8")

##### Appendix §7: Sensitivity analyses for nonparametric mediation analyses, Figures 3-4

harm.sens.ci <- medsens(harm.mod.ci, rho.by=0.01,sims=1500,effect.type="indirect")
fair.sens.ci <- medsens(fair.mod.ci, rho.by=0.01,sims=1500,effect.type="indirect")
ingroup.sens.ci <- medsens(ingroup.mod.ci, rho.by=0.01,sims=1500,effect.type="indirect")
authority.sens.ci <- medsens(authority.mod.ci, rho.by=0.01,sims=1500,effect.type="indirect")
purity.sens.ci <- medsens(purity.mod.ci, rho.by=0.01,sims=1500,effect.type="indirect")

summary(harm.sens.ci)
summary(fair.sens.ci)
summary(ingroup.sens.ci)
summary(authority.sens.ci)
summary(purity.sens.ci)

dev.new(width=12, height=8)
par(mfrow=c(3,5))

plot(harm.sens.ci, sens.par="rho", main = "Harm")
plot(fair.sens.ci, sens.par="rho", main = "Fairness")
plot(ingroup.sens.ci, sens.par="rho", main = "Ingroup")
plot(authority.sens.ci, sens.par="rho", main = "Authority")
plot(purity.sens.ci, sens.par="rho", main = "Purity")
plot(harm.sens.ci, sens.par="R2", main = "Harm", sign.prod="positive")
plot(fair.sens.ci, sens.par="R2", main = "Fairness", sign.prod="positive")
plot(ingroup.sens.ci, sens.par="R2", main = "Ingroup", sign.prod="positive")
plot(authority.sens.ci, sens.par="R2", main = "Authority", sign.prod="positive")
plot(purity.sens.ci, sens.par="R2", main = "Purity", sign.prod="positive")
plot(harm.sens.ci, sens.par="R2", main = "Harm", sign.prod="negative")
plot(fair.sens.ci, sens.par="R2", main = "Fairness", sign.prod="negative")
plot(ingroup.sens.ci, sens.par="R2", main = "Ingroup", sign.prod="negative")
plot(authority.sens.ci, sens.par="R2", main = "Authority", sign.prod="negative")
plot(purity.sens.ci, sens.par="R2", main = "Purity", sign.prod="negative")

harm.sens.mi <- medsens(harm.mod.mi, rho.by=0.01,sims=1500,effect.type="indirect")
fair.sens.mi <- medsens(fair.mod.mi, rho.by=0.01,sims=1500,effect.type="indirect")
ingroup.sens.mi <- medsens(ingroup.mod.mi, rho.by=0.01,sims=1500,effect.type="indirect")
authority.sens.mi <- medsens(authority.mod.mi, rho.by=0.01,sims=1500,effect.type="indirect")
purity.sens.mi <- medsens(purity.mod.mi, rho.by=0.01,sims=1500,effect.type="indirect")

summary(harm.sens.mi)
summary(fair.sens.mi)
summary(ingroup.sens.mi)
summary(authority.sens.mi)
summary(purity.sens.mi)

par(mfrow=c(3,5))
plot(harm.sens.mi, sens.par="rho", main = "Harm")
plot(fair.sens.mi, sens.par="rho", main = "Fairness")
plot(ingroup.sens.mi, sens.par="rho", main = "Ingroup")
plot(authority.sens.mi, sens.par="rho", main = "Authority")
plot(purity.sens.mi, sens.par="rho", main = "Purity")
plot(harm.sens.mi, sens.par="R2", main = "Harm", sign.prod="positive")
plot(fair.sens.mi, sens.par="R2", main = "Fairness", sign.prod="positive")
plot(ingroup.sens.mi, sens.par="R2", main = "Ingroup", sign.prod="positive")
plot(authority.sens.mi, sens.par="R2", main = "Authority", sign.prod="positive")
plot(purity.sens.mi, sens.par="R2", main = "Purity", sign.prod="positive")
plot(harm.sens.mi, sens.par="R2", main = "Harm", sign.prod="negative")
plot(fair.sens.mi, sens.par="R2", main = "Fairness", sign.prod="negative")
plot(ingroup.sens.mi, sens.par="R2", main = "Ingroup", sign.prod="negative")
plot(authority.sens.mi, sens.par="R2", main = "Authority", sign.prod="negative")
plot(purity.sens.mi, sens.par="R2", main = "Purity", sign.prod="negative")

##### Appendix §8: Figure 5: mediation effect of libertarianism on moral foundations


dat.mediate.ci <- data[which(!is.na(data$ci.s1)),]
dat.mediate.mi <- data[which(!is.na(data$mi.s1)),]
dat.mediate.iso <- data[which(!is.na(data$iso.s1)),]


model.m.ci <- glm(Libertarian ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1 + age + Male + education_2 + education_3 + education_4 + education_5 , data=dat.mediate.ci, family=binomial("probit"))
model.ci <- lm(ci.s1 ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1 + Libertarian + age + Male + education_2 + education_3 + education_4 + education_5 , data=dat.mediate.ci)
model.m.mi <- glm(Libertarian ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1 + age + Male + education_2 + education_3 + education_4 + education_5 , data=dat.mediate.mi, family=binomial("probit"))
model.mi <- lm(mi.s1 ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1 + Libertarian + age + Male + education_2 + education_3 + education_4 + education_5 , data=dat.mediate.mi)
model.m.iso <- glm(Libertarian ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1 + age + Male + education_2 + education_3 + education_4 + education_5 , data=dat.mediate.iso, family=binomial("probit"))
model.iso <- lm(iso.s1 ~ mfq_harm1 + mfq_fairness1 + mfq_ingroup1 + mfq_authority1 + mfq_purity1 + Libertarian + age + Male + education_2 + education_3 + education_4 + education_5 , data=dat.mediate.iso)

harm.mod.ci <- mediate(model.m.ci,model.ci, sims=1500, boot=FALSE, treat="mfq_harm1", mediator="Libertarian")
fair.mod.ci <- mediate(model.m.ci,model.ci, sims=1500, boot=FALSE, treat="mfq_fairness1", mediator="Libertarian")
ingroup.mod.ci <- mediate(model.m.ci,model.ci, sims=1500, boot=FALSE, treat="mfq_ingroup1", mediator="Libertarian")
authority.mod.ci <- mediate(model.m.ci,model.ci, sims=1500, boot=FALSE, treat="mfq_authority1", mediator="Libertarian")
purity.mod.ci <- mediate(model.m.ci,model.ci, sims=1500, boot=FALSE, treat="mfq_purity1", mediator="Libertarian")

summary(harm.mod.ci)
summary(fair.mod.ci)
summary(ingroup.mod.ci)
summary(authority.mod.ci)
summary(purity.mod.ci)

harm.mod.mi <- mediate(model.m.mi,model.mi, sims=1500, boot=FALSE, treat="mfq_harm1", mediator="Libertarian")
fair.mod.mi <- mediate(model.m.mi,model.mi, sims=1500, boot=FALSE, treat="mfq_fairness1", mediator="Libertarian")
ingroup.mod.mi <- mediate(model.m.mi,model.mi, sims=1500, boot=FALSE, treat="mfq_ingroup1", mediator="Libertarian")
authority.mod.mi <- mediate(model.m.mi,model.mi, sims=1500, boot=FALSE, treat="mfq_authority1", mediator="Libertarian")
purity.mod.mi <- mediate(model.m.mi,model.mi, sims=1500, boot=FALSE, treat="mfq_purity1", mediator="Libertarian")

summary(harm.mod.mi)
summary(fair.mod.mi)
summary(ingroup.mod.mi)
summary(authority.mod.mi)
summary(purity.mod.mi)

par(mfrow=c(2,3))
plot(harm.mod.mi, main="Harm", xlim=c(-0.5,0.6))
plot(fair.mod.mi, main="Fairness",xlim=c(-0.5,0.6))
plot(ingroup.mod.mi, main="Ingroup",xlim=c(-0.5,0.6))
plot(authority.mod.mi, main="Authority",xlim=c(-0.5,0.6))
plot(purity.mod.mi, main="Purity",xlim=c(-0.5,0.6))

harm.mod.iso <- mediate(model.m.iso,model.iso, sims=1500, boot=FALSE, treat="mfq_harm1", mediator="Libertarian")
fair.mod.iso <- mediate(model.m.iso,model.iso, sims=1500, boot=FALSE, treat="mfq_fairness1", mediator="Libertarian")
ingroup.mod.iso <- mediate(model.m.iso,model.iso, sims=1500, boot=FALSE, treat="mfq_ingroup1", mediator="Libertarian")
authority.mod.iso <- mediate(model.m.iso,model.iso, sims=1500, boot=FALSE, treat="mfq_authority1", mediator="Libertarian")
purity.mod.iso <- mediate(model.m.iso,model.iso, sims=1500, boot=FALSE, treat="mfq_purity1", mediator="Libertarian")

summary(harm.mod.iso)
summary(fair.mod.iso)
summary(ingroup.mod.iso)
summary(authority.mod.iso)
summary(purity.mod.iso)

par(mfrow=c(1,3), mar=c(5.1,1.1,4.1,0), oma=c(0,4,0,0))
#CI Panel
plot(0,0,xlim=c(-0.4,0.8), ylim=c(1,15), axes=FALSE, xlab="", ylab="", type="n", main="Cooperative Internationalism")
	polygon(c(-0.5,0.8,0.8,-0.5),c(15.5,15.5,12.5,12.5), border=FALSE, col="gray92")
	polygon(c(-0.5,0.8,0.8,-0.5),c(9.5,9.5,6.5,6.5), border=FALSE, col="gray92")
	polygon(c(-0.5,0.8,0.8,-0.5),c(3.5,3.5,0.5,0.5), border=FALSE, col="gray92")

for (i in 1:5){
	for (j in c(1,4,7)){
		points(med.ci[i,j],(15-((i-1)*3+(j-1)/3)), pch=16)
		lines(c(med.ci[i,j+1], med.ci[i,j+2]),c(rep(15-((i-1)*3+(j-1)/3),2)))
	}
}
abline(v=0)
axis(1, xlab="Effect size")
for (i in seq(15,3,by=-3)){
	text(c("ACME", "Direct", "Total"),x=-0.4,y=c(i,i-1,i-2),cex=0.7)
}
mtext(c("Harm", "Fairness", "Ingroup", "Authority", "Purity"),side=2, at=seq(14,2,by=-3),line=2.5)
#abline(h=seq(12.5,3.5,by=-3),lty=3)

#MI Panel
plot(0,0,xlim=c(-0.4,0.8), ylim=c(1,15), axes=FALSE, xlab="", ylab="", type="n", main="Militant Internationalism")
polygon(c(-0.5,0.8,0.8,-0.5),c(15.5,15.5,12.5,12.5), border=FALSE, col="gray92")
	polygon(c(-0.5,0.8,0.8,-0.5),c(9.5,9.5,6.5,6.5), border=FALSE, col="gray92")
	polygon(c(-0.5,0.8,0.8,-0.5),c(3.5,3.5,0.5,0.5), border=FALSE, col="gray92")

for (i in 1:5){
	for (j in c(1,4,7)){
		points(med.mi[i,j],(15-((i-1)*3+(j-1)/3)), pch=16)
		lines(c(med.mi[i,j+1], med.mi[i,j+2]),c(rep(15-((i-1)*3+(j-1)/3),2)))
	}
}
abline(v=0)
axis(1, xlab="Effect size")
#for (i in seq(15,3,by=-3)){
#	text(c("ACME", "Direct", "Total"),x=-0.6,y=c(i,i-1,i-2),cex=0.7)
#}
#abline(h=seq(12.5,3.5,by=-3),lty=3)

#Iso panel
plot(0,0,xlim=c(-0.4,0.8), ylim=c(1,15), axes=FALSE, xlab="", ylab="", type="n", main="Isolationism")
	polygon(c(-0.5,0.8,0.8,-0.5),c(15.5,15.5,12.5,12.5), border=FALSE, col="gray92")
	polygon(c(-0.5,0.8,0.8,-0.5),c(9.5,9.5,6.5,6.5), border=FALSE, col="gray92")
	polygon(c(-0.5,0.8,0.8,-0.5),c(3.5,3.5,0.5,0.5), border=FALSE, col="gray92")

for (i in 1:5){
	for (j in c(1,4,7)){
		points(med.iso[i,j],(15-((i-1)*3+(j-1)/3)), pch=16)
		lines(c(med.iso[i,j+1], med.iso[i,j+2]),c(rep(15-((i-1)*3+(j-1)/3),2)))
	}
}
abline(v=0)
axis(1, xlab="Effect size")

summary(harm.mod.ci)
summary(fair.mod.ci)
(0.1642+0.2279)/2 #0.1961 through mediation, 0.80395 through direct effects

summary(ingroup.mod.ci)
summary(authority.mod.ci)
summary(purity.mod.ci)
(-0.01286+-0.36041+-0.16987)/3 (#-0.1810467 through mediaton, 1.181047 through direct)

summary(harm.mod.mi)
summary(fair.mod.mi)
(0.03441+0.0886)/2 (#0.061505 through mediation, 0.938495 through direct)

summary(ingroup.mod.mi) 
summary(authority.mod.mi)
summary(purity.mod.mi)
(0.000220-0.01420-0.01678)/3 (#-0.01025333 through mediation, 1.010253 through direct)